/*

Copyright 1994 by Todd M. Miller

Permission to use, copy, modify, and distribute this
software and its documentation for any purpose and without
fee is hereby granted, provided that the above copyright
notice appear in all copies and that both that copyright
notice and this permission notice appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.
The author makes no representations about the suitability of
this software for any purpose.  It is provided "as is"
without express or implied warranty.

*/


#include <string.h>
#include "periodic.h"
#include "info.h"

extern struct info elements[TotStructs];
extern  int Ptable[11][19]; /* element positions in the periodic table */
extern  int coordinates[180][2];
int Xpos = 1;
int Ypos = 1;
int label_option = 1; /* Group label option */
int element_option = 1; /* Visual Enhancement Option */
int shell_option = 1; /* Electronic configuration option */
int number_option = 1; /* Numbered Table option */


		
void ask_user ( void )
{

  int key;
  int element;
  int savex,savey;
  int i,j;
  int moving = 0;

  while(!moving) {
    element = Ptable[Ypos][Xpos];
    if(element_option) {  /* View atom Information on Periodic Table */
      mvaddstr(4,25,"   ");
      move(4,25);
      printw("%d",elements[element].Number);
      mvaddstr(5,30,"               ");
      mvaddstr(5,30,elements[element].Name);
      mvaddstr(6,30,"             ");
      mvaddstr(6,30,elements[element].AtmWeight);
    }
    if(shell_option) {  /* view electronic configuration on periodic tbl */
      mvaddstr(17,5,"electron configuration:");
      move(18,2);
      for(i=2;i<80;i++)
	addstr(" ");
      mvaddstr(18,2,elements[element].e_config);
    }
	
    reverse(1);
    move(coordinates[element][0]-1,coordinates[element][1]-1);
    if(number_option) {
      printw("%d",elements[element].Number);
      if(elements[element].Number > 9 && elements[element].Number < 100)
	addstr(" ");
      else if (elements[element].Number > 99)
	;
      else if (elements[element].Number <= 9)
	addstr("  ");
    } else {
      addstr("   ");
    }
    move(coordinates[element][0],coordinates[element][1]-1);
    addstr(" ");
    addstr(elements[element].Symbol);
    if(strlen(elements[element].Symbol) == 1)
      addstr(" ");
    bold(0);
    reverse(0);
    move(23,79);
    refresh();
    key = ttinp();
    savex = Xpos;
    savey = Ypos;

  dokey:
    switch(key) {

    case 27:
      key = ttinp();
      key = ttinp();
      switch(key) {
      case 'A':     /* Up arrow */
	key = 'k';
	break;
      case 'B':     /* Down Arrow */
	key = 'j';  
	break;
      case 'C':     /* Right Arrow */
	key = 'l';
	break;
      case 'D':     /* Left Arrow */
	key = 'h';
	break;
      case '2':     /* Help button, do and func keys F9-F20 */
	key = ttinp();
	switch(key) {
	case '8':    /* Help key */
	  key = '?';
	  break;
	case '9':    /* Do key */
	  key = 'i';
	  break;
	}
	i = ttinp();  /* extra character */
	break;
	
      default:
	key = 0;
      }
      goto dokey;
      break;
      
    case 'A':
    case 'a':  /* Information screen on element */
      element = Ptable[Ypos][Xpos];
      do_information( element );
      break;


    case 'B':
    case 'b':  /* table of bond energies */
      do_bondeng();  
      clear();
      draw_table();
      refresh();
      break;



    case 'C':
    case 'c':
      do_constants();     /* Table of Physical Constants */
      clear();
      draw_table();
      refresh();
      break;

 
    case 'D':
    case 'd': 
      clear();  /* Defintions  sub-menu */
      do_definitions();
      clear();
      draw_table();
      refresh();
      break;

    case 'E':
    case 'e': 
      do_en();   /* Electronegativity table */
      clear();
      draw_table();
      refresh();
      break;

    case 'F':
    case 'f': 
      do_formula();  /* Formula weight calculator */
      clear();
      draw_table();
      refresh();
      break;
      
    case 'G':
    case 'g':    /* Named group highlighting */
      /* Turn the element mol weight option off */
	mvaddstr(4,25,"   ");
	mvaddstr(5,30,"               ");
	mvaddstr(6,30,"             ");
      
      /* turn the electron configuration option off */
      move(17,1);
      for(i=1;i<40;i++)
	addstr(" ");
      move(18,2);
      for(i=2;i<80;i++)
	addstr(" ");
      /* turn off current element highlighting */
      bold(0);
      reverse(0);
      move(coordinates[element][0]-1,coordinates[element][1]-1);
      if(number_option) {
	printw("%d",elements[element].Number);
	if(elements[element].Number > 9)
	  addstr(" ");
	else
	  addstr("  ");
      } else {
	addstr("   ");
      }
      move(coordinates[element][0],coordinates[element][1]-1);
      addstr(" ");
      addstr(elements[element].Symbol);
      if(strlen(elements[element].Symbol) == 1)
	addstr(" ");
      
      /* do groups */
      do_groups();
      clear();
      draw_table();
      break;


    case 'H':
    case 'h': Xpos = Xpos - 1;
      if(Xpos == 0){
	if(Ypos<=7 && Ypos!=1) {
	  Ypos = Ypos - 1;
	  Xpos = 18;
	  break;
	}
	if(Ypos==1) {
	  bell();
	  Xpos = savex;
	  break;
	}
      }
      if (Ypos > 8 && Xpos ==3) {
	Ypos = Ypos - 3;
	break;
      }
      if((Ypos==6 || Ypos == 7) && Xpos==3) {
	Ypos = Ypos + 3;
	Xpos = 17;
	break;
      }
      while(Xpos > 0 && (Ptable[Ypos][Xpos] == 0)) {
	Xpos = Xpos -1;
	if(Xpos < 1) {
	  bell();
	  Xpos = savex;
	  break;
	}
      }
      break;
      
    case 13:
    case 'I':
    case 'i':  /* Table of common ions */
      do_ions();
      clear();
      draw_table();
      refresh();
      break;

    case 'J':
    case 'j':    /* move up */
      Ypos = Ypos + 1;
      if(Ypos > 10) {
	bell();
	Ypos = savey;
	break;
      }
      if(Ypos == 8) {
	Ypos = Ypos + 1;
	if(Xpos < 5)
	  Xpos = 4;
	break;
      }
      if(Ypos == 7 && Xpos == 18) {
	Ypos = 9;
	Xpos = 17;
	break;
      }
      while(Ypos < 11 && (Ptable[Ypos][Xpos] == 0)) {
	Ypos = Ypos + 1;
	if(Ypos >= 10) {
	  bell();
	  Ypos = savey;
	  break;
	}
      }
      break;
      
    case 'K':
    case 'k': /* move down */
      Ypos = Ypos - 1;
      if(Ypos == 1) {
	if(Xpos < 3) {
	  Xpos = 1;
	  break;
	} else if (Xpos > 12) {
	  Xpos = 18;
	  break;
	}
      }
      if(Ypos == 3) {
	if(Xpos>=3 && Xpos <= 12) {
	  if(Xpos< 8) {
	    Xpos = 2;
	  } else {
	    Xpos = 13;
	  }
	  break;
	}
      }	
      if(Ypos <= 0) {
	bell();
	Ypos = savey;
	break;
      }
      while(Ypos > 0 && (Ptable[Ypos][Xpos] == 0)) {
	Ypos = Ypos - 1;
	if(Ypos < 1) {
	  bell();
	  Ypos = savey;
	  break;
	}
      }
      break;

    case '9':   /* tab key */
    case 'L':
    case 'l':  /* move left */
      Xpos = Xpos + 1;
      if(Xpos == 4 && (Ypos == 6 || Ypos == 7)) {
	Ypos = Ypos + 3;
	break;
      } else if (Xpos >= 19) {
	Ypos = Ypos + 1; /* from the right hand side,left hand side in */
	Xpos = 1;  /* atomic number session */
	break;
      } else if (Xpos >= 18) {
	if (Ypos > 8) { /* Lanthanides and Actinides */
	  Ypos = Ypos - 3;
	  Xpos = 4;
	  break;
	}
      }
      while((Xpos < 19) && (Ptable[Ypos][Xpos] == 0)){
	Xpos = Xpos + 1;
	if(Xpos > 18) {
	  bell();
	  Xpos = savex;
	  break;
	}
      } 
      break;

    case 'M':
    case 'm': /* Mineral Substances Module */
      do_minerals();   
      clear();
      draw_table();
      refresh();
      break;

      
    case 'N':
    case 'n': 
      do_nobel();  /* Nobel Prize winner summary */
      clear();
      draw_table();
      refresh();
      break;
      
    case 'O':
    case 'o': /* Electrode Potentials */
      do_eseries();
      clear();
      draw_table();
      refresh();
      break;


    case 'P':
    case 'p': 
      do_conductors();  /* Metals as conductors */
      clear();
      draw_table();
      refresh();
      break;

      
    case 'Q':
    case 'q': /* Converions */
      do_conversion();
      clear();
      draw_table();
      refresh();
      break;


      
    case 'R':
    case 'r': /* Ionic Radii */
      do_radii(element);
      clear();
      draw_table();
      break;
      
    case 'S':
    case 's':  /* Table of solubility products */
      do_solubility();
      clear();
      draw_table();
      refresh();
      break;
      
    case 'T':
    case 't':  /* History of chemical discoveries */
      do_timeline();
      clear();
      draw_table();
      refresh();
      break;

    case 'U':
    case 'u':
      do_metric(); /* show metric prefixes */
      clear();
      draw_table();
      refresh();
      break;

    case 'V':
    case 'v': 
      do_tables();  /* Different formats of the periodic table */
      clear();
      draw_table();
      refresh();
      break;


    case 'W':
    case 'w':
      if(shell_option) { /* show electronic configuration on pt */
	shell_option = 0;
	move(17,1);
	for(i=1;i<40;i++)
	  addstr(" ");
	move(18,2);
	for(i=2;i<80;i++)
	  addstr(" ");
      } else {
	shell_option = 1;
      }
      break;

      
    case 'X':
    case 'x':    /* Number the table */
      if(number_option) {
	number_option = 0;
      } else {
	number_option = 1;
      }
      do_numbers();
      refresh();
      break;

    case 'Y':
    case 'y':   /* display element molecular weight at the top of PT */
      if(element_option) {
	element_option = 0;
	mvaddstr(4,25,"   ");
	mvaddstr(5,30,"               ");
	mvaddstr(6,30,"             ");
      } else {
	element_option = 1;
      }
      break;

    case 'Z':
    case 'z':   /* Group labels and numbers on left hand side (periods) */
      if(label_option) {
	label_option = 0;
	do_labels(0);
      } else {
	label_option = 1;
	do_labels(1);
      }
      refresh();
      break;

      
    case ' ': moving = 1; /* Exit program */
      break;

    case '?': /* Give program help */
      do_help();
      clear();
      draw_table();
      refresh();
      break;
      
    default: break;
      
    }
    /* Unbold the  old element */
    bold(0);
    reverse(0);
    element = Ptable[savey][savex];
    move(coordinates[element][0]-1,coordinates[element][1]-1);
    if(number_option) {
      printw("%d",elements[element].Number);
      if(elements[element].Number > 9)
	addstr(" ");
      else
	addstr("  ");
    } else {
      addstr("   ");
    }
    move(coordinates[element][0],coordinates[element][1]-1);
    addstr(" ");
    addstr(elements[element].Symbol);
    if(strlen(elements[element].Symbol) == 1)
      addstr(" ");
    
    refresh();
  }
  return;
}

