/*

Copyright 1994 by Todd M. Miller

Permission to use, copy, modify, and distribute this
software and its documentation for any purpose and without
fee is hereby granted, provided that the above copyright
notice appear in all copies and that both that copyright
notice and this permission notice appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.
The author makes no representations about the suitability of
this software for any purpose.  It is provided "as is"
without express or implied warranty.

*/

/*  Table of Approximate Bond Energies From Inorganic Chemistry, 3rd ed.,
     James E. Huheey, Harper & Row, New York, 1983, Appendix E.
*/

#include <string.h>
#include "periodic.h"

  struct BE {
    char *line;
  } Bondeng[] = {
    {"H-H   432.00"},
    {"H-F   565"},
    {"H-Cl  428.02"},
    {"H-Br  362"},
    {"H-I   294.6"},
    {"H-O   458.8"},
    {"H-S   363"},
    {"H-Se  276"},
    {"H-Te  238"},
    {"H-N   368"},
    {"H-P   322"},
    {"H-As  247"},
    {"H-C   411"},
    {"H-Si  318"},
    {"H-B   389"},
    {"H-Cu  276"},
    {"H-Ag  230"},
    {"H-Au  285"},
    {"H-Li  243"},
    {"H-Na  197"},
    {"H-K   180"},
    {"H-Rb  163"},
    {"H-Cs  176"},
    {"Li-Li 105"},
    {"Li-F  573"},
    {"Li-Cl 464"},
    {"Li-Br 418"},
    {"Li-I  347"},
    {"Na-Na 72.4"},
    {"Na-F  477.0"},
    {"Na-Cl 407.9"},
    {"Na-Br 362.8"},
    {"Na-I  304.2"},
    {"K-K   49.4"},
    {"K-F   490"},
    {"K-Cl  423"},
    {"K-Br  378.7"},
    {"K-I   326"},
    {"Rb-Rb 45.2"},
    {"Rb-F  490"},
    {"Rb-Cl 444"},
    {"Rb-Br 385"},
    {"Rb-I  331"},
    {"Cs-Cs 43.5"},
    {"Cs-F  502"},
    {"Cs-Cl 435"},
    {"Cs-Br 416.3"},
    {"Cs-I  335"},
    {"Be-Be 208"},
    {"Be-F  632"},
    {"Be-Cl 461"},
    {"Be-Br 724"},
    {"Be-I  289"},
    {"Be=O  444"},
    {"Mg-Mg 129"},
    {"Mg-F  513"},
    {"Mg-Cl 406"},
    {"Mg-Br 339"},
    {"Mg-I  264"},
    {"Mg=O  377"},
    {"Ca-Ca 105"},
    {"Ca-F  550"},
    {"Ca-Cl 429"},
    {"Ca-Br 402"},
    {"Ca-I  326"},
    {"Ca=O  460"},
    {"Ca=S  310"},
    {"Sr-Sr 84"},
    {"Sr-F  553"},
    {"Sr-Cl 429"},
    {"Sr-Br 405"},
    {"Sr-I  335"},
    {"Sr=O  347"},
    {"Sr=S  222"},
    {"Ba-F  578"},
    {"Ba-Cl 475"},
    {"Ba-Br 427"},
    {"Ba-I  360"},
    {"Ba=O  561"},
    {"Ba=S  396.2"},
    {"Sc-Sc 108.4"},
    {"Sc-F  594"},
    {"Sc-Cl 460.6"},
    {"Sc-Br 391.2"},
    {"Sc-I  322"},
    {"Y-Y   156.1"},
    {"Y-F   628"},
    {"Y-Cl  494"},
    {"Y-Br  431"},
    {"Y-I   362.8"},
    {"La-La 241.0"},
    {"La-F  657"},
    {"La-Cl 513.0"},
    {"La-Br 439"},
    {"La-I  363.6"},
    {"Zr-F  646.8"},
    {"Zr-Cl 489.5"},
    {"Zr-Br 423.8"},
    {"Zr-I  345.6"},
    {"Hf-F  649.4"},
    {"Hf-Cl 494.9"},
    {"Hf-Br 431"},
    {"Hf-I  360"},
    {"Fe-Fe 156"},
    {"Ni-Ni 228.0"},
    {"Cu-Cu 190.4"},
    {"Ag-F  305"},
    {"Ag-Cl 314"},
    {"Ag-Br 289"},
    {"Ag-I  230"},
    {"Zn-F  400.0"},
    {"Zn-Cl 319.7"},
    {"Zn-Br 268.6"},
    {"Zn-I  207.5"},
    {"Cd-F  326"},
    {"Cd-Cl 224.7"},
    {"Cd-Br 242.7"},
    {"Cd-I  190.8"},
    {"Hg-F  268"},
    {"Hg-Cl 224.7"},
    {"Hg-Br 184.9"},
    {"Hg-I  146.6"},
    {"B-B   293"},
    {"B-F   613.1"},
    {"B-Cl  456"},
    {"B-Br  377"},
    {"B-C   372"},
    {"Al-F  583.0"},
    {"Al-Cl 420.7"},
    {"Al-C  255"},
    {"Ga-Ga 113"},
    {"Ga-F  469"},
    {"Ga-Cl 354.0"},
    {"Ga-Br 301.7"},
    {"Ga-I  237.2"},
    {"In-In 100"},
    {"C-C   345.6"},
    {"C=C   602"},
    {"C=-C  835.1"},
    {"C-F   485"},
    {"C-Cl  327.2"},
    {"C-Br  285"},
    {"C-I   213"},
    {"C-O   357.7"},
    {"C=O   798.9"},
    {"C=-O  1071.9"},
    {"C-S   272"},
    {"C=S   573"},
    {"C-N   304.6"},
    {"C=N   615"},
    {"C=-N  887"},
    {"C-P   264"},
    {"Si-Si 222"},
    {"Si-F  565"},
    {"Si-Cl 381"},
    {"Si-Br 310"},
    {"Si-I  234"},
    {"Si-O  452"},
    {"Si-S  293"},
    {"Ge-Ge 188"},
    {"Ge=Ge 272"},
    {"Sn-Sn 146"},
    {"N=N   418"},
    {"N=-N  941.69"},
    {"N-F   283"},
    {"N-Cl  313"},
    {"N-O   201"},
    {"N=O   607"},
    {"P=-P  481"},
    {"P-O   335"},
    {"P=O   544"},
    {"P=S   335"},
    {"As-As 146"},
    {"As-O  301"},
    {"As=O  389"},
    {"O=O   493.59"},
    {"O-F   189.5"},
    {"S=S   424.7"},
    {"S-F   284"},
    {"Se=Se 272"},
    {"Te-Te 126"},
    {"Te=Te 218"},
    {"I-I   148.95"},
    {"Br-Br 190.16"},
    {"Cl-Cl 239.7"},
    {"F-F   154.8"},
    {"At-At 115.9"},
    {"EndOfData"}};

void do_bondeng ( void )
{

  int key;
  int item, column;
  
  item = 0;
  while(strcmp(Bondeng[item].line,"EndOfData") != 0) {
    bondeng_label();
    for(column=4; column <= 21; column++) {
      if(strcmp(Bondeng[item].line,"EndOfData") != 0)
	mvaddstr(column,5,Bondeng[item++].line);
      else
	break;
      if(strcmp(Bondeng[item].line,"EndOfData") != 0)
	mvaddstr(column,25,Bondeng[item++].line);
      else
	break;
      if(strcmp(Bondeng[item].line,"EndOfData") != 0)
	mvaddstr(column,45,Bondeng[item++].line);
      else
	break;
      if(strcmp(Bondeng[item].line,"EndOfData") != 0)
	mvaddstr(column,65,Bondeng[item++].line);
      else
	break;
    }
    if(listcommand() == 32)
      return;
    clear();
  }
  mvaddstr( 0, 35, "Reference");
  mvaddstr( 3, 0, " Inorganic Chemistry, 3rd ed.; James E. Huheey, Harper & Row, New York,");
  mvaddstr( 4, 0, " 1983, Appendix E.");
  refresh();
  key = ttinp();
  return;
}

void bondeng_label()
{
  clear();
  mvaddstr(0,27,"Approximate Bond Energies");
  mvaddstr(2,5,"Bond  kJ/mol");
  mvaddstr(2,25,"Bond  kJ/mol");
  mvaddstr(2,45,"Bond  kJ/mol");
  mvaddstr(2,65,"Bond  kJ/mol");
  return;
}
