/*

Copyright 1994 by Todd M. Miller

Permission to use, copy, modify, and distribute this
software and its documentation for any purpose and without
fee is hereby granted, provided that the above copyright
notice appear in all copies and that both that copyright
notice and this permission notice appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.
The author makes no representations about the suitability of
this software for any purpose.  It is provided "as is"
without express or implied warranty.

*/


#include "periodic.h"

/* Recommended Constant Values of Fundemental  Physical Constants,
 Chemistry of the Elements, Greenwood, N.N., Earnshaw, A.; 
 Pergamon Press, New York, 1984 , pg. 1543 */

struct PC {
  char *line;
} pconstants[] = {
  {"Permeability        u                                      -7    -1    "},
  {"of vacuum            0                    12.5663706144 x 10  Hz m      "},
  {" "},
  {"Speed of light                                         -1               "},
  {"in a vacuum         c                     2.99792458 m s              0.004 "},
  {" "},
  {"Permittivity                2 -1                  -1                    "},
  {"of a                e = (u c )            8.85418782 F m              0.008 "},
  {"vacuum               0    0                                             "},
  {" "},
  {"Elementary                                             -19              "},
  {"charge              e                     1.6021892 X 10   C          2.9   "},
  {" "},
  {"Plank                                                 -34    -1         "},
  {"constant            h                     6.626176 X 10   J Hz        5.4   "},
  {" "},
  {"Plank               +                                  -34              "},
  {"constant            h = h/2pi             1.0545887 x 10   J s        5.4 "},
  {" "},

  {"                                                       23   -1         "},
  {"Avagadro's          N                     6.022045 X 10   mol         5.1 "},
  {"constant             A                                                  "},
  {" "},
  {"Atomic                     -3     -1                   -27              "},
  {"mass                1u = (10 kg mol )/N   1.6605655 X 10   kg         5.1"},
  {"unit                                   A                        "},
  {" "},
  {"Electron                                               -30              "},
  {"rest                m                     0.9109534 X 10   kg         5.1 "},
  {"mass                 e                                                 "},
  {" "},
  {"Electron                                                               "},
  {"rest                m                     0.5110034 MeV               2.8 "},
  {"mass                 e                                                 "},
  {" "},
  {"Proton                                                 -27             "},
  {"rest                m                     1.6726485 X 10   kg         5.1"},
  {"mass                 p                                            "},

  {"Proton                                                            "},
  {"rest                m                     935.2796 MeV                2.8"},
  {"mass                 p                                                 "},
  {" "},
  {"Neutron                                                -27              "},
  {"rest                m                     1.6749543 X 10  kg          5.1"},
  {"mass                 n                                                 "},
  {" "},
  {"Neutron                                                                "},
  {"rest                m                     939.5731 MeV                2.8 "},
  {"mass                 n                                                 "},
  {" "},
  {"Ratio, proton                                                          "},
  {"mass to             m  / m                1836.15152                  0.38"},
  {"electron mass        p    e                                            "},
  {" "},
  {"Faraday             F = N e               9.648456 X 10  C mol        2.8"},
  {"constant                 A                                            "},
  {" "},

  {"                                                          7 -1          "},
  {"Rydberg             R                     1.097373177 x 10  m         0.075"},
  {"constant             infinity                                         "},
  {" "},
  {"                                                         -10          "},
  {"Bohr                a  = alpha/4piR        0.52917706 X 10   m        0.82"},
  {"radius               0             infinity                             "},
  {" "},
  {"Electron                                                             "},
  {"g                   1/2g = u / u           1.0011596567               0.0035"},
  {"factor                  e   e   B                                       "},
  {" "},
  {"                         +                        -24   -1           "},
  {"Bohr                u = eh/2m              9.274078 X 10   J T        3.9"},
  {"Magneton             B       e                                       "},
  {" "},
  {"                                                       -27   -1       "},
  {"Nuclear             u = eh/2m              5.050824 x 10   J T        3.9"},
  {"Magneton             N       p                                       "},
  {" "},

  {"Electron                                               -24   -1       "},
  {"magnetic            u                      9.284832 x 10   J T        3.9"},
  {"moment               e                                               "},
  {" "},
  {"Proton                                                  -26   -1     "},
  {"magnetic            u                      1.4106171 x 10   J T       3.9"},
  {"moment               p                                               "},
  {" "},
  {"Proton magnetic                                           -3          "},
  {"moment in           u / u                  1.521032209 x 10           0.011"},
  {"Bohr magnetons       p   B                                            "},
  {" "},
  {"Ratio, electron                                                        "},
  {"to proton           u / u                  658.2106880                0.010"},
  {"magnetic moments     e   p                                             "},
  {" "},
  {" "},
  {" "},
  {"Proton                                                   8 -1 -1       "},
  {"gyromagnetic        y                      2.6751987 X 10  s  T       2.8 "},
  {"ratio                p                                                 "},
  {" "},
  {"Molar                                                  -1 -1           "},
  {"gas                 R                      8.31441 J mol  K           31"},
  {"constant                                                               "},
  {" "},
  {"Molar volume,                                          3   -1           "},
  {"ideal gas           V = RT /P              0.02241383 m  mol          31"},
  {"T=273.15K,P=1atm                                                      "},
  {" "},
  {"Boltzman                                               -23              "},
  {"constant            k = R/N                1.380662 X 10              32"},
  {"                           A                                         "},
  {" "},
  {"Gravitational                                        -11    2  -2       "},
  {"constant            G                      6.6720 X 10   N m  Kg      615 "},
  {" "}};


void do_constants()
{


  int key;
  int line, column, page;
  
  line = 0;
  for(page =1; page <= 6; page++) {
    constants_label();
    for(column = 4; column <= 22; column++) {
      mvaddstr(column,0,pconstants[line++].line);
    }
    if(listcommand() == 32)
      return;
    clear();
  }

  mvaddstr(0,35, "Reference");
  mvaddstr(3,2,"Chemistry of the Elements, Greenwood, N.N., Earnshaw, A.; Pergamon Press,");
  mvaddstr(4,2,"New York, 1984, page 1543.");
  mvaddstr( 23, 16, "Press any key to Return to the Periodic Table");
  refresh();
  key = ttinp();
  return;
}

void constants_label()
{

  clear();
  mvaddstr(0,15,"Constant Values of Some Fundemental Physical Constants");
  mvaddstr(2,0,
	   "  Quantity         Symbol                  Value                  Uncertainty");
  mvaddstr(3,69,"(ppm)");
  return;
}
