/*

Copyright 1994 by Todd M. Miller

Permission to use, copy, modify, and distribute this
software and its documentation for any purpose and without
fee is hereby granted, provided that the above copyright
notice appear in all copies and that both that copyright
notice and this permission notice appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.
The author makes no representations about the suitability of
this software for any purpose.  It is provided "as is"
without express or implied warranty.

*/


#include <string.h>
#include "periodic.h"

struct CONVERTS{
  char Units[40];
  double Factor;
};

char *conversion_choice(int x, struct CONVERTS *ConvertBlock, char *Units);
double convert (double from, char *FUnits, char *TUnits, 
		struct CONVERTS *ConvertBlock);


struct CONVERTS LENGTH[] = {
  {"kilometers",1.0E-3},{"meters",1.0},{"centimeters",1.0E2},
  {"decimeters",1.0E1},{"millimeters",1.0E3},{"micrometers",1.0E6},
  {"angstroms",1.0E10},{"nanometers",1.0E9},{"picometers",1.0E12},
  {"inches",0.0254},{"feet",3.2808399},{"yards",1.0936133},
  {"miles",0.00062137119},
  {"END",0.0}};

struct CONVERTS AREA[] = {
  {"sq.centimeters",1.0/10000},{"sq.feet",10.763910},
  {"sq.inches",1550.0031},
  {"sq.kilometers",1.0/1.0E-6},{"acres",0.00024710538},
  {"hectares",0.0001},
  {"sq.meters",1.0},{"sq.miles",3.8610216E-7},{"sq.millimeters",1.0E6},
  {"sq.yards",1.195990},{"END",0.0}};

struct CONVERTS CURRENT[] = {
  {"kiloamperes",1.0E-3},{"amperes",1.0},{"milliamperes",1.0E3},
  {"microamperes",1.0E6},{"nanoamperes",1.0E9},{"picoamperes",1.0E12},
  {"femtoamperes",1.0E15},{"coulombs/sec",1.0},
  {"faradays/second",1.036377E-5},{"END",0.0}};

struct CONVERTS DENSITY[] = {
  {"grams/cu.centimeter",0.001},{"kilograms/cu.meter",1.0},
  {"lbs/cu.foot",0.062427961},{"lbs/cu.inch",03.6127292E-5},
  {"END",0.0}};

struct CONVERTS FREQUENCY[] = {
  {"gigahertz",1.0E-9},{"megahertz",1.0E-6},{"kilohertz",1.0E-3},
  {"hertz",1.0},{"millihertz",1.0E3},{"microhertz",1.0E6},
  {"nanohertz", 1.0E9},{"picohertz",1.0E12},
  {"END",0.0}};

struct CONVERTS MASS[] = {
  {"grams",1000.0},
  {"kilograms",1.0},{"milligrams",1.0E6},{"grains",15432.358},
  {"ounces (avdp)",35.273962},{"dynes",980665},
  {"pounds (avdp)",2.2046226},{"slugs",0.06852177},
  {"tons (short)",0.0011023113},{"a.m.u.s",1.661e27},
  {"END",0.0}};

struct CONVERTS SPEED[] = {
  {"feet/minute",196.85039},{"feet/second",3.2808399},
  {"kilometers/hour",3.6},{"kilometers/minute",0.06},
  {"miles/hour",2.2308339},{"centimeters/second",1.0E2},
  {"meters/second",1.0},{"END",0.0}};

struct CONVERTS TEMPERATURE[] = {
  {"celcius",0.0},{"kelvin",0.0},{"fahrenheit",0.0},{"END",0.0}};

struct CONVERTS TIME[] = {
  {"years",3.156e7},{"months",3.156e7/12.0},{"days",1.0/86400.0},
  {"hours",1.0/3600.0},{"minutes",1.0/60.0},{"seconds",1.0},
  {"milliseconds",1.0E3},{"microseconds",1.0E6},{"nanoseconds",1.0E9},
  {"picoseconds",1.0E12},{"femptoseconds",1.0E15},{"END",0.0}};

struct CONVERTS VOLUME[] = {
  {"cu.centimeters",1.0E-3},{"cu.feet",0.035314667},
  {"cu.inches",61.023744},{"cu.yards",0.0013079506},
  {"gallons",0.26417205},{"liters",1.0},{"quarts",1.0566882},
  {"milliliters",1E3},{"pints",2.1133764},{"ounces",33.814023},
  {"END",0.0}};

struct CONVERTS FORCE[] = {
  {"newtons",1.0},{"dynes",100000.0},{"pounds",0.22480894},
  {"END",0.0}};

struct CONVERTS PRESSURE[] = {
  {"torr",1.0},{"mm of Hg at 0C",1.0},{"atms",0.0013157895},
  {"bars",0.00133322},{"dynes/sq.centimeter",1333.224},
  {"grams/sq.centimeter",1.35951},{"kilgrams/sq.meter",13.5951},
  {"Pascals",13.5951},{"pounds/sq.foot",2.78450},
  {"pounds/sq.inch",0.0193368},{"END",0.0}};

struct CONVERTS WORK[] = {
  {"netwon-meters",1.0},{"dyne-centimeters",1.0E7},
  {"gram-centimeters",10197.162},{"kilogram-meters",0.10197162},
  {"joules",1.0},{"ergs",1.0e7},{"calories",1.0/4.186},{"b.t.u.s",1.0/1055.0},
  {"electron-volts",1.602e19},{"kilowatt-hours",1.0/3.600e6},
  {"foot-pounds",0.73756215},{"END",0.0}};

struct CONVERTS POWER[] = {
  {"Watts",1.0},{"B.t.u./hour",3.41443},{"B.t.u./sec",0.000948451},
  {"calories, grams/hour",860.421},{"ergs/sec",1.0E7},
  {"foot-pounds/minute",44.2537},{"horsepower",0.00134102},
  {"joules/sec",1.0},{"kilowatts",0.001},{"liter-atm/hour",35.5282},
  {"END",0.0}};

struct CONVERTS QELEC[] = {
  {"coulumbs",1.0},{"ampere-hours",0.0002777},
  {"electric charge",6.24196E18},
  {"faradays",1.036377E-5},{"END",0.0}};

struct CHOICE {
  char Name[40];
  struct CONVERTS *Units;
  int x,y;
  int left,right,up,down;
} Choices [] = {
  {"Length",LENGTH,0,0},
  {"Mass",MASS,0,0},
  {"Time",TIME,0,0},
  {"Volume",VOLUME,0,0},
  {"Temperature",TEMPERATURE,0,0},
  {"Speed",SPEED,0,0},
  {"Frequency",FREQUENCY,0,0},
  {"Density",DENSITY,0,0},
  {"Area",AREA,0,0},
  {"Electric Current",CURRENT,0},
  {"Force",FORCE,0},
  {"Pressure",PRESSURE,0},
  {"Work, Energy, Heat",WORK,0},
  {"Power",POWER,0},
  {"Quantity of Electricity",QELEC,0},
  {"Exit",0,0},
  {"EndOfList",0,0}};


void do_conversion ( void )
{

  int x,y;
  int item;
  int rowonemin;
  int rowonemax;
  int maxchoices;
  int key,i,lastitem;
  char FromUnits[30], *fromunits;
  char ToUnits[30], *tounits;
  double from, answer;
  float input;

  x = 2;
  y = 3;

  fromunits = FromUnits;
  tounits = ToUnits;

  item = 0;
  while(y < 22 && strcmp(Choices[item].Name,"EndOfList") != 0) {
    Choices[item].x = x;
    Choices[item].y = y;
    Choices[item].left = -1;
    if(item > 0)
      Choices[item].up = item - 1;
    else
      Choices[item].up = -1;
    Choices[item].down = item + 1;
    Choices[item].right = -1;
    item++;
    y += 2;
  }
  rowonemin = 0;
  rowonemax = item;
  Choices[item-1].down = -1;
  x = 42;
  y = 3;
  while(y < 22 && strcmp(Choices[item].Name,"EndOfList") != 0) {
    Choices[item].x = x;
    Choices[item].y = y;
    Choices[rowonemin].right = item;
    Choices[item].right = -1;
    Choices[item].left = rowonemin++;
    if(item > rowonemax)
      Choices[item].up = item - 1;
    else
      Choices[item].up = -1;
    Choices[item].down = item + 1;
    item++;
    y += 2;
  }
  maxchoices = item - 1;
  Choices[maxchoices].down = -1;

  lastitem = 0;
  item = 0;

 Page:
  clear();
  mvaddstr(0,27,"Choose A Conversion Domain");
  for(i=0;i <= maxchoices;i++) 
    mvaddstr(Choices[i].y,Choices[i].x,Choices[i].Name);

 loop:
  bold(0);
  reverse(0);
  mvaddstr(Choices[lastitem].y,Choices[lastitem].x,Choices[lastitem].Name);
  bold(1);
  reverse(1);
  mvaddstr(Choices[item].y,Choices[item].x,Choices[item].Name);
  bold(0);
  reverse(0);
  refresh();
  move(23,79);
  key = ttinp();

 Do_Key:
  switch(key) {

  Next_Page:

  case 27:
    key = ttinp();
    key = ttinp();
    switch(key) {
    case 'A':     /* Up arrow */
      key = 'k';
      break;
    case 'B':     /* Down Arrow */
      key = 'j';  
      break;
    case 'C':     /* Right Arrow */
      key = 'l';
      break;
    case 'D':     /* Left Arrow */
      key = 'h';
      break;
    case '2':     /* Help button, do and func keys F9-F20 */
      key = ttinp();
      switch(key) {
      case '8':    /* Help key */
	key = '?';
	break;
      case '9':    /* Do key */
	key = 13;
	break;
      }
      i = ttinp();  /* extra character */
      break;
      
    default:
      key = 0;
    }
    goto Do_Key;
    break;

  case 'J': /* down */
  case 'j':
    lastitem = item;
    if(Choices[lastitem].down > -1 )
      item = Choices[lastitem].down;
    else
      bell();
    break;

  case 'k':
  case 'K': /* up */
    lastitem = item;
    if(Choices[lastitem].up > -1)
      item = Choices[lastitem].up;
    else
      bell();
    break;

  case 'h':
  case 'H': /* left */
    lastitem = item;
    if(Choices[lastitem].left > -1)
      item = Choices[lastitem].left;
    else
      bell();
    break;


  case 'l':
  case 'L': /* Right */
    lastitem = item;
    if(Choices[lastitem].right > -1)
      item = Choices[lastitem].right;
    else
      bell();
    break;

  case 13: /* topic select */
    clear();
    if(strcmp(Choices[item].Name,"Exit") ==0)
      return;

    mvaddstr(3,0,"Enter Quantity");
    mvaddstr(4,0,"Exponents are Expressed as E");
    mvaddstr(5,0,"               -6");
    mvaddstr(6,0,"e.g.:  2.3 X 10    = 2.3E-6");
    move(3,15);
    refresh();
    echo();
    scanw("%f",&input);
    noecho();
    from = input;
    clear();
    move(2,5);
    printw("%e",from);
    refresh();
    fromunits = conversion_choice(10, Choices[item].Units, FromUnits);
    mvaddstr(2,18,fromunits);
    mvaddstr(2,40,"=");
    refresh();
    tounits = conversion_choice(42, Choices[item].Units, ToUnits);
    if(strcmp(Choices[item].Name,"Temperature") == 0) {
      if(strcmp(fromunits,"celcius") == 0) 
	from += 273.15;
      else if (strcmp(fromunits,"fahrenheit") == 0)
        from = ((from-32.0)*5/9) + 273.15;

      if(strcmp(tounits,"celcius") == 0)
	answer = from - 273.15;
      else if (strcmp(tounits,"fahrenheit") == 0)
	answer = (from-273.15)*9/5 + 32.0;
      else
	answer = from;
   } else {
      answer = convert ( from, fromunits, tounits, Choices[item].Units);
   }
    move(2,42);
    printw("%e %s ", answer, tounits);
    mvaddstr(23,27,"Press any key to continue");
    refresh();
    key = ttinp();
    goto Page;

  case 32:  /* space bar quits */
    return;

  default:
    break;
    
  }
  goto loop;

 out:
  return;
}



char *conversion_choice(int x, struct CONVERTS *Converts, char *Answer)
{

  struct conv {
    char Name[30];
    int x,y;
  } Menu[20];

  int y;
  int item;
  int lastitem;
  int TotalItems;
  int key;
  int i;

  y = 5;
  item = 0;
  while(strcmp(Converts[item].Units,"END") != 0) {
    Menu[item].x = x;
    Menu[item].y = y;
    strcpy(Menu[item].Name,Converts[item].Units);
    item++;
    y ++;
  }

  TotalItems = item;
  strcpy(Menu[TotalItems].Name,"EXIT");

  

 Page:
  bold(0);
  reverse(0);
  item = 0;
  while(strcmp(Menu[item].Name,"EXIT") != 0) {
    mvaddstr(Menu[item].y,Menu[item].x,Menu[item].Name);
    item++;
  }
  mvaddstr(Menu[item].y,Menu[item].x,Menu[item].Name);

  lastitem = 0;
  item = 0;

 loop:
  bold(0);
  reverse(0);
  mvaddstr(Menu[lastitem].y,Menu[lastitem].x,Menu[lastitem].Name);
  bold(1);
  reverse(1);
  mvaddstr(Menu[item].y,Menu[item].x,Menu[item].Name);
  bold(0);
  reverse(0);
  refresh();

  key = ttinp();
 
 Do_Key:
  switch(key) {

  case 27:
    key = ttinp();
    key = ttinp();
    switch(key) {
    case 'A':     /* Up arrow */
      key = 'k';
      break;
    case 'B':     /* Down Arrow */
      key = 'j';  
      break;
    case 'C':     /* Right Arrow */
      key = 'l';
      break;
    case 'D':     /* Left Arrow */
      key = 'h';
      break;
    case '2':     /* Help button, do and func keys F9-F20 */
      key = ttinp();
      switch(key) {
      case '8':    /* Help key */
	key = '?';
	break;
      case '9':    /* Do key */
	key = 13;
	break;
      }
      i = ttinp();  /* extra character */
      break;
      
    default:
      key = 0;
    }
    goto Do_Key;
    break;

  case 'J': /* down */
  case 'j':
    lastitem = item++;
    if(item >= TotalItems) {
      bell();
      item--;
    }
    break;

  case 'k':
  case 'K': /* up */
    lastitem = item--;
    if(item < 0) {
      bell();
      item++;
    }
    break;

  case 13:
    reverse(1);
    mvaddstr(Menu[item].y,Menu[item].x,Menu[item].Name);
    reverse(0);
    strcpy(Answer,Menu[item].Name);
    return Answer;
    
  case 32:
    strcpy(Answer,"Exit");
    return Answer;

  default:
    bell();
    break;
  }
  goto loop;
}



double convert (double number, char *fromunits, char *tounits, 
		  struct CONVERTS *Converts)
{
  int units;

  units = 0;
  while(strcmp(Converts[units].Units,"END") != 0) {
    if(strcmp(fromunits,Converts[units].Units) == 0) 
      break;
    else
      units++;
  }

  number /= Converts[units].Factor;

  units = 0;
  while(strcmp(Converts[units].Units,"END") != 0) {
    if(strcmp(tounits,Converts[units].Units) == 0) 
      break;
    else
      units++;
  }

  number *= Converts[units].Factor;

  return number;
}

