/*

Copyright 1994 by Todd M. Miller

Permission to use, copy, modify, and distribute this
software and its documentation for any purpose and without
fee is hereby granted, provided that the above copyright
notice appear in all copies and that both that copyright
notice and this permission notice appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.
The author makes no representations about the suitability of
this software for any purpose.  It is provided "as is"
without express or implied warranty.

*/


#include <string.h>
#include <ctype.h>
#include "periodic.h"
#include "info.h"

extern struct info elements[TotStructs];

void do_formula ( void )
{
  char string[80];
  char *fstring;
  char formula[80];
  char *rstring;
  int thisch;

  struct form {
    char element[3];
    short no;
  } table [30];

  char Atom[3];
  short fpointer = 0;
  short oparen[40][2];
  short opnum;
  short paren[40][2];
  short pnum;
  short depth;
  short multiplier;
  short wasmult;
  int s;
  short blank[40][3];
  short bnum = 0;
  int i,j;
  int x = 1;
  int y = 20;
  short wasdigit;
  short wasblank;
  int key;
  double FW,PM; /* Formula Weight */
  char *dot;
  int tsigfig,sigfig;
  
  clear();
  mvaddstr(1,0,"Rules for Formula Input:");
  mvaddstr(3,1,"1. Atomic symbols must be accurate with the second letter being lowercase");
  mvaddstr(4,4,"for elements with two letter symbols.  (examples: Cl, Br, N, etc...).");
  mvaddstr(5,1,"2. Number of elements must be integers and 1's are implicit.  The numbers");
  mvaddstr(6,4,"are generally placed after the atomic symbol (examples:  Na2CO3, KCl,");
  mvaddstr(7,4,"CH4, etc...).");
  mvaddstr(8,1,"3. Parentheses may be used to enclose groups and a number appended to");
  mvaddstr(9,4,"indicate the number of occurances of the group (examples:  Fe(CN)6,");
  mvaddstr(10,4,"CrCl2(CH3CN)2, C(C(CH3)3)4, etc...).");
  mvaddstr(11,1,"4. An integer may proceed a group to indicate multiple occurances of the");
  mvaddstr(12,4,"group if the entire string is delimited by blank spaces (examples:");
  mvaddstr(13,4,"5H2O, Fe2O3 3NH3, 4CH3, etc...). ");
  mvaddstr(14,1,"5. No square brackets ([,]), charges (+,-), or special characters may");
  mvaddstr(15,4,"be used.");
  mvaddstr(16,1,"6. The string may be up to 79 characters long.");
  mvaddstr(20,1,"Molecular Formula:");
  refresh();
  move(20,20);
  echo();
  nl();
#ifdef VMS
  getstr(&string);
#else
  getstr(string);
#endif
  noecho();
  nonl();

  fstring = &string[0];
  i = strlen(fstring);
  if(i == 0) return;
  j = 0;
  i -= 1;
  while(i >= 0)
    formula[j++] = fstring[i--];
  formula[j] = (char ) 0;
  rstring = &formula[0];
  wasmult = 0;
  s = 1;
  multiplier = 0;
  Atom[0] = Atom[1] = Atom[2] = 0;
  opnum = -1;
  pnum = 0;
  depth = 0;
  blank[0][0] = 1;
  blank[0][1] = 0;
  blank[0][2] = 0;

 loop:
  thisch = *rstring++;
  if(isdigit(thisch)) {
    if(wasmult)
      s = s*10;
    multiplier += (thisch-48) * s;
    wasmult = 1;
    
  } 
  else if (islower(thisch)) {
    Atom[1] = thisch;
    s = 1;
  } 
  else if (isupper(thisch)) {
    Atom[0] = thisch;
    strcpy(table[fpointer].element,&Atom[0]);
    Atom[0] = Atom[1] = Atom[2] = 0;
    if(multiplier == 0)
      table[fpointer++].no = 1;
    else
      table[fpointer++].no = multiplier;
    s = 1;
    wasmult = multiplier = 0;
  } 
  else if (thisch == '(') {
    if(wasmult)
      oparen[opnum+depth][1] = multiplier;
    else
      oparen[opnum+depth][1] = 1;
    oparen[opnum+depth][0] = fpointer - 1; 
    depth -=1;
    if(depth == 0) opnum =pnum-1;
    wasmult = multiplier = 0;
  } 
  else if (thisch == ')') {
    if(wasmult)
      paren[pnum][1] = multiplier;
    else 
      paren[pnum][1] = 1;
    wasmult = multiplier = 0;
    paren[pnum++][0] = fpointer;
    depth += 1;
  } 
  else if (thisch == ' ') {
    if(wasmult)
      blank[bnum][0] = multiplier;
    else
      blank[bnum][0] = 1;
    blank[bnum++][2] = fpointer - 1;
    blank[bnum][1] = fpointer;
    wasmult = multiplier = 0;
  }

  if(strlen(rstring) != 0) {
    goto loop;
  }

  if(wasmult) {
    blank[bnum][0] = multiplier;
    blank[bnum][2] = fpointer-1;
  } else {
    bnum -= 1;
  }
  
  pnum -= 1;
  opnum -= 1;
  i = 0;
  
  while(i <= pnum) { 
    for(j = paren[i][0]; j <= oparen[i][0]; j++)
      table[j].no *= paren[i][1];
    i += 1;
  };
  
  i = 0;
  while (i <= bnum) {
    for(j = blank[i][1]; j <= blank[i][2]; j++)
      table[j].no *= blank[i][0];
    i += 1;
  };

  clear();
  mvaddstr(1,1,"Molecular Formula:");
  y = 1;
  x = 20;
  wasblank = 1;
  wasdigit = 0;
  for(i = 0; i < strlen(string); i++) {
    if(isdigit(string[i])) {
      if(!wasblank )
	mvaddch(y+1,x++,string[i]);
      else
	mvaddch(y,x++,string[i]);
      wasblank = 0;
      wasdigit = 1;
    } else if (string[i] == ' ') {
      wasblank = 1;
      wasdigit = 0;
      mvaddch(y,x++,string[i]);
    } else {
      mvaddch(y,x++,string[i]);
      wasdigit = 0;
      wasblank = 0;
    }
  }

      
  for(i = fpointer-1; i >= 0; i--) {
    if(table[i].no != 0) {
      for(j = i-1; j >= 0; j--) {
	if(strcmp(&table[j].element[0],&table[i].element[0]) == 0) {
	  if(table[j].no != 0) {
	    table[i].no += table[j].no;
	    table[j].no = 0;
	  }
	}
      }
    }
  }

  FW = 0.0;
  tsigfig = 10;
  sigfig = 100;
  mvaddstr(5,1,"Empirical Formula: ");
  y = 5;
  x = 20;
  for(i = (fpointer - 1); i >= 0; i-- ) {
    if(table[i].no != 0) {
      mvaddstr(y,x++,table[i].element);
      for(j = 1; j < TotStructs; j++) {
	if(strcmp(table[i].element,elements[j].Symbol) == 0) {
	  FW += table[i].no * elements[j].AtomWeight;
	  dot = strchr(elements[j].AtmWeight,'.'); 
	  if(dot != 0) 
	    tsigfig = strlen(++dot);
	  else
	    tsigfig = 0;
	  if(tsigfig < sigfig)
	    sigfig = tsigfig;
	}
      }
      if(table[i].element[1] != 0)
	x++;
      move(y+1,x);
      if(table[i].no != 1)
	printw("%d",table[i].no);
      x++;
      if(table[i].no > 9)
	x++;
      if(table[i].no > 99)
	x++;
    }
  }
  mvaddstr(3,45,"Formula Weight:");
  if(sigfig == 0)
    printw("%9.0f a.m.u.",FW);
  if(sigfig == 1)
    printw("%9.1f a.m.u.",FW);
  if(sigfig == 2)
    printw("%9.2f a.m.u.",FW);
  if(sigfig == 3)
    printw("%9.3f a.m.u.",FW);
  if(sigfig == 4)
    printw("%9.4f a.m.u.",FW);
  if(sigfig == 5)
    printw("%9.5f a.m.u.",FW);
  bold(1);
  mvaddstr(8,28,"Percent by mass composition");
  bold(0);
  y = 10;
  x = 2;
  for (i = (fpointer-1) ; i >= 0; i--) {
    if(table[i].no != 0) {
      for(j = 1; j < TotStructs; j++) {
	if(strcmp(table[i].element,elements[j].Symbol) == 0) {
	  PM = ((table[i].no*elements[j].AtomWeight)/FW)*100;
	  move(y++,x);
	  printw("%2.2f %% %s by weight",PM ,table[i].element);
	}
      }
    }
    if(y == 22) {
      x = 40;
      y = 10;
    }
  }
  mvaddstr(16,13,"Press Any Key to Return to the Periodic Table");
  refresh();
  key = ttinp();
  return;
}

