/*

Copyright 1994 by Todd M. Miller

Permission to use, copy, modify, and distribute this
software and its documentation for any purpose and without
fee is hereby granted, provided that the above copyright
notice appear in all copies and that both that copyright
notice and this permission notice appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.
The author makes no representations about the suitability of
this software for any purpose.  It is provided "as is"
without express or implied warranty.

*/


#include <string.h>
#include "periodic.h"

struct SOL {
  char *line;
} solprod[] = {
{"PbBr2      4.6 X 10 -6"},
{"Hg2Br2     1.3 X 10 -22"},
{"AgBr       5.0 X 10 -13"},
{"BaCO3      1.6 X 10 -9"},
{"CdCO3      5.2 X 10 -12"},
{"CaCO3      4.7 X 10 -9"},
{"CuCO3      2.5 X 10 -10"},
{"FeCO3      2.1 X 10 -11"},
{"PbCO3      1.5 X 10 -15"},
{"MgCO3      1   X 10 -11"},
{"MnCO3      8.8 X 10 -11"},
{"Hg2CO3     9.0 X 10 -12"},
{"NiCO3      1.4 X 10 -7"},
{"Ag2CO3     8.2 X 10 -12"},
{"SrCO3      7   X 10 -10"},
{"ZnCO3      2   X 10 -10"},
{"PbCl2      1.6 X 10 -5"},
{"Hg2Cl2     1.1 X 10 -18"},
{"AgCl       1.7 X 10 -10"},
{"BaCrO4     8.5 X 10 -11"},
{"PbCrO4     2   X 10 -16"},
{"Hg2CrO4    2   X 10 -9"},
{"Ag2CrO4    1.9 X 10 -12"},
{"SrCrO4     3.6 X 10 -5"},
{"BaF2       2.4 X 10 -5"},
{"CaF2       3.9 X 10 -11"},
{"PbF2       4   X 10 -8"},
{"MgF2       8   X 10 -8"},
{"SrF2       7.9 X 10 -10"},
{"Al(OH)3    5   X 10 -33"},
{"Ba(OH)2    5.0 X 10 -3"},
{"Cd(OH)2    2.0 X 10 -14"},
{"Ca(OH)2    1.3 X 10 -6"},
{"Cr(OH)3    6.7 X 10 -31"},
{"Co(OH)2    2.5 X 10 -16"},
{"Co(OH)3    2.5 X 10 -43"},
{"Cu(OH)2    1.6 X 10 -19"},
{"Fe(OH)2    1.8 X 10 -15"},
{"Fe(OH)3    5   X 10 -38"},
{"Pb(OH)2    4.2 X 10 -15"},
{"Mg(OH)2    8.9 X 10 -12"},
{"Mn(OH)2    2   X 10 -13"},
{"Hg(OH)2    3   X 10 -26"},
{"Ni(OH)2    1.6 X 10 -16"},
{"AgOH       2.0 X 10 -8"},
{"Sr(OH)2    3.2 X 10 -4"},
{"Sn(OH)2    3   X 10 -27"},
{"Zn(OH)2    4.5 X 10 -17"},
{"PbI2       8.3 X 10 -9"},
{"Hg2I2      4.5 X 10 -29"},
{"AgI        8.5 X 10 -17"},
{"BaC2O4     1.5 X 10 -8"},
{"CaC2O4     1.3 X 10 -9"},
{"PbC2O4     8.3 X 10 -12"},
{"MgC2O4     8.6 X 10 -5"},
{"Ag2C2O4    1.1 X 10 -11"},
{"SrC2O4     5.6 X 10 -8"},
{"Ba3(PO4)2  6   X 10 -39"},
{"Ca3(PO4)2  1.3 X 10 -32"},
{"Pb3(PO4)2  1   X 10 -54"},
{"Ag3PO4     1.8 X 10 -18"},
{"Sr3(PO4)2  1   X 10 -31"},
{"BaSO4      1.5 X 10 -9"},
{"CaSO4      2.4 X 10 -5"},
{"PbSO4      1.3 X 10 -8"},
{"Ag2SO4     1.2 X 10 -5"},
{"SrSO4      7.6 X 10 -7"},
{"Bi2S3      1.6 X 10 -72"},
{"CdS        1.0 X 10 -28"},
{"CoS        5   X 10 -22"},
{"CuS        8   X 10 -37"},
{"FeS        4   X 10 -19"},
{"PbS        7   X 10 -29"},
{"MnS        7   X 10 -16"},
{"HgS        1.6 X 10 -54"},
{"NiS        3   X 10 -21"},
{"Ag2S       5.5 X 10 -51"},
{"SnS        1   X 10 -26"},
{"ZnS        2.5 X 10 -22"},
{"NaHCO3     1.2 X 10 -3"},
{"KClO4      8.9 X 10 -3"},
{"K2[PtCl6]  1.4 X 10 -6"},
{"AgC2H3O2   2.3 X 10 -3"},
{"AgCN       1.6 X 10 -14"},
{"AgCNS      1.0 X 10 -12"},
{"EndOfData"}};


void do_solubility()
{


  int key;
  int item, column;

  item = 0;
  while(strcmp(solprod[item].line,"EndOfData") != 0) {
    solubility_label();
    for(column=4;column <= 21; column++) {
      if(strcmp(solprod[item].line,"EndOfData") != 0)
	mvaddstr(column,0,solprod[item++].line);
    }
    for(column=4;column <= 21; column++) {
      if(strcmp(solprod[item].line,"EndOfData") != 0)
	mvaddstr(column,27,solprod[item++].line);
    }
    for(column=4;column <= 21; column++) {
      if(strcmp(solprod[item].line,"EndOfData") != 0)
	mvaddstr(column,56,solprod[item++].line);
    }
    if(listcommand() == 32)
      return;
    clear();
  }
  mvaddstr( 0,35, "Refrence");
  mvaddstr( 3, 0, "  Extracted From ``Chemistry'', Mortimer, Charles E.; Wadsworth, Belmont,");
  mvaddstr( 4, 0, "                  California, 1983, page 745");
  refresh();
  key = ttinp();
  return;
}


void solubility_label()
{
  clear();
  mvaddstr(0,30,"Solubility Products");
  mvaddstr(1,29,"at 20 degrees Celcius");
  mvaddstr(2,0,"Compound   Solubility      Compound   Solubility        Compound   Solubility");
  return;
}
