/*

Copyright 1994 by Todd M. Miller

Permission to use, copy, modify, and distribute this
software and its documentation for any purpose and without
fee is hereby granted, provided that the above copyright
notice appear in all copies and that both that copyright
notice and this permission notice appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.
The author makes no representations about the suitability of
this software for any purpose.  It is provided "as is"
without express or implied warranty.

*/

#include <string.h>
#include "periodic.h"

struct NL {
  char *line;
} Newlands[] = {
  {"                                                                       "},
  {" +-------------------------------------------------------------------+ "},
  {" |           Periodic Table of J.A.R. Newlands - 1864-1866           | "},
  {" >-------------------------------------------------------------------< "},
  {" |H          F         Cl        Co,Ni        Br        I       Pt,Ir| "},
  {" |Li         Na        K         Cu           Rb        Cs      Os   | "},
  {" |Be         Mg        Ca        Zn           Sr        Ba,V    Hg   | "},
  {" |B          Al        Cr        Y            Ce,La     Ta      Tl   | "},
  {" |C          Si        Ti        In           Zr        W       Pb   | "},
  {" |N          P         Mn        As           Di,Mo     Nb      Bi   | "},
  {" |O          S         Fe        Se           Rh,Ru     Au      Th   | "},
  {" +-------------------------------------------------------------------+ "},
  {"                                                                       "},
  {"``The Development of Modern Chemistry''; Ihde, Arron J., Harper & Row, "},
  {"  New York, 1964, p. 242.                                              "},
  {"  Presented at the Royal Chemical Society in 1866.  Newlands' work on  "},
  {"  the periodicity of the elements preceeded Mendeleev's and in 1887 he "},
  {"  was awarded the Davy Metal.  He is credited with discovering the pre-"},
  {"  liminary aspects of the periodic law, recognized especially here for "},
  {"  his table demonstrating ``The Law of Octaves and the Causes of       "},
  {"  Numerical Relations Between Atomic Weights.''                        "}
  };

struct MD {
  char *line;
} Mendeleev[] = {
  {"                   Mendeleev's Periodic Table of 1872                   "},
  {""},
  {""},
  {" Series     I      II     III     IV       V      VI      VII     VIII  "},
  {" "},
  {"   1        H                                                           "},
  {"   2        Li     Be     B       C        N      O       F             "},
  {"   3        Na     Mg     Al      Si       P      S       Cl            "},
  {"   4        K      Ca     ?       Ti       V      Cr      Mn      Fe,Co "},
  {"                                                                  Ni,Cu "},
  {"   5       (Cu)    Zn     ?       ?        As     Se      Br            "},
  {"   6        Rb     Sr    Yt       Zr        Nb     Mo      ?      Ru,Rh "},
  {"                                                                  Pd,Ag "},
  {"   7       (Ag)    Cd    In       Sn        Sb     Te      I            "},
  {"   8        Cs     Ba    Di       Ce                                    "},
  {"   9                     Er       La        Ta     W              Os,Ir "},
  {"   10                                                             Pt,Au "},
  {"   11      (Au)    Hg    Tl       Pb        Bi                          "},
  {"   12                             Th               U                    "},
  {"EndOfPage"}};

struct CP {
  char *line;
} CompressedPT[] = {
  {"                   Long Form of the Current Periodic Table"},
  {"        HHe"},
  {""},
  {"       LiBe                                                 B C N O FNe"},
  {""},
  {"       NaMg                                                AlSi P SClAr"},
  {""},
  {"        KCa                            ScTi VCrMnFeCoNiCuZnGaGeAsSeBrKr"},
  {""},
  {"       RbSr                             YZrNbMoTcRuRhPdAgCdInSnSbTe IXe"},
  {""},
  {"       CsBaLaCePrNdPmSmEuGdTbDyHoErTmYbLuHfTa WReOsIrPtAuHgTlPbBiPoAtRn"},
  {""},
  {"       FrRaAcThPa UNpPuAmCmBkCfEsFmMdNoLrDbJlRfBhHnMt"},
  {"EndOfPage"}};

struct ZH1 {
  char *line;
} Zhuvikin1[] = {
  {"G.V. Zhuvikin (St. Petersburg University) & R. Hefferlin (Southern College, TN)"},
  {"            n = +1    n = +2    n = +3    n = +4    n = +5    n = +6    n = +7"},
  {"     ms = -1/2 +1/2 -1/2 +1/2 -1/2 +1/2 -1/2 +1/2 -1/2 +1/2 -1/2 +1/2 -1/2 +1/2"},
  {" "},
  {"l=0,ml =  0 H   He   Li   Be   Na   Mg   K    Ca   Rb   Sr   Cs   Ba   Fr   Ra"},
  {" "},
  {"    ml = -1           B    C   Al   Si   Ga   Ge   In   Sn   Tl   Pb"},
  {"l=1,ml =  0           N    O    P    S   As   Se   Sb   Te   Bi   Po"},
  {"    ml = +1           F   Ne   Cl   Ar   Br   Kr    I   Xe   At   Rn"},
  {" "},
  {"    ml = -2          Sc   Ti    Y   Zr   Lu   Hf   Lr   Db"},
  {"    ml = -1           V   Cr   Nb   Mo   Ta    W   Jl   Rf"},
  {"l=2,ml =  0          Mn   Fe   Tc   Ru   Re   Os   Bh   Hn"},
  {"    ml = +1          Co   Ni   Rh   Pd   Ir   Pt   Mt"},
  {"    ml = -2          Cu   Zn   Ag   Cd   Au   Hg"},
  {" "},
  {"    ml = -3                     La  Ce   Ac   Th"},
  {"    ml = -2                     Pr  Nd   Pa    U"},
  {"    ml = -1                     Pm  Sm   Np   Pu"},
  {"l=3,ml =  0                     Eu  Gd   Am   Cm"},
  {"    ml = +1                     Tb  Dy   Bk   Cf"},
  {"    ml = +2                     Ho  Er   Es   Fm"},
  {"    ml = +3                     Tm  Yb   Md   No"},
  {"EndOfPage"}};

struct HF {
  char *line;
} Hefferlin1[] = {
  {"G.V. Zhuvikin (St. Petersburg University) & R. Hefferlin (Southern College, TN)"},
  {"              n = +1            n = +2            n = +3            n = +4 "},
  {"md =       -1/2     +1/2     -1/2     +1/2     -1/2     +1/2     -1/2     +1/2"},
  {"ms =    -1/2+1/2 -1/2+1/2 -1/2+1/2 -1/2+1/2 -1/2+1/2 -1/2+1/2 -1/2+1/2 -1/2+1/2"},
  {""},
  {"l=0, ml=0 H  He   Li  Be   Na  Mg    K  Ca   Rb  Sr   Cs  Ba   Fr  Ra"},
  {""},
  {"    ml=-1                   B   C   Al  Si   Ga  Ge   In  Sn   Tl  Pb "},
  {"l=1, ml=0                   N   O    P   S   As  Se   Sb  Te   Bi  Po "},
  {"    ml=+1                   F  Ne   Cl  Ar   Br  Kr    I  Xe   At  Rn"},
  {"    ml=-2                                    Sc  Ti    Y  Zr   Lu  Hf   Lr  Db"},
  {"    ml=-1                                     V  Cr   Nb  Mo   Ta   W   Jl  Rf"},
  {"l=2, ml=0                                    Mn  Fe   Tc  Ru   Re  Os   Bh  Hn"},
  {"    ml=+1                                    Co  Ni   Rh  Pd   Ir  Pt   Mt"},
  {"    ml=+2                                    Cu  Zn   Ag  Cd   Au  Hg"},
  {"    ml=-3                                                      La  Ce   Ac  Th"},
  {"    ml=-2                                                      Pr  Nd   Pa   U"},
  {"    ml=-1                                                      Pm  Sm   Np  Pu"},
  {"l=3, ml=0                                                      Eu  Gd   Am  Cm"},
  {"    ml=+1                                                      Tb  Dy   Bk  Cf"},
  {"    ml=+2                                                      Ho  Er   Es  Fm"},
  {"    ml=+3                                                      Tm  Yb   Md  No"},
  {"EndOfPage"}};

struct ZHB {
  char *line;
} ZH[] = {
  {"H   He                          Reformatted Veiws of The Current Periodic Table"},
  {"Li  Be"},
  {"Na  Mg   B   C   N   O   F  Ne  "},
  {"K   Ca  Al  Si   P   S  Cl  Ar"},
  {"Rb  Sr  Ga  Ge  As  Sc  Br  Kr  Sc  Ti   V  Cr  Mn  Fe  Co  Ni  Cu  Zn "},
  {"Cs  Ba  In  Sn  Sb  Tc   I  Xe   Y  Zr  Nb  Mo  Tc  Ru  Rh  Pd  Ag  Cd"},
  {"Fr  Ra  Tl  Pb  Bi  Po  At  Rn  Lu  Hf  Ta  W   Re  Os  Ir  Pt  Au  Hg  >1"},
  {"                                Lr  Db  Jl  Rf  Bh  Hn  Mt              >2"},
  {""},
  {"                                  1>  La Ce Pr Nd Pm Sm Eu Gd Tb Dy Ho Er Tm Yb"},
  {"                                  2>  Ac Th Pa  U Np Pu Am Cm Bk Cf Es Fm Md No"},
  {""},
  {"		             Compressed View"},
  {"      HHe   "},
  {"     LiBe"},
  {"     NaMg   B C N O FNe  "},
  {"      KCa  AlSi P SClAr "},
  {"     RbSr  GaGeAsScBrKr  ScTi VCrMnFeCoNiCuZn "},
  {"     CsBa  InSnSbTc IXe   YZrNbMoTcRuRhPdAgCd"},
  {"     FrRa  TlPbBiPoAtRn  LuHfTaW ReOsIrPtAuHg  LaCePrNdPmSmEuGdTbDyHoErTmYb"},
  {"                         LrDbJlRfBhHnMt        AcThPa UNpPuAmCmBkCfEsFmMdNo"},
  {"EndOfPage"}};



void do_tables()
{

  int key;
  int i;
  int column;
  int item;
  
  clear();
  for(i=0;i<=20;i++) {  
    move(i+1,5);
    addstr(Newlands[i].line);
  }
  if(listcommand() == 32)
    return;

  clear();
  column = 1;
  item = 0;
  while(strcmp(Mendeleev[item].line,"EndOfPage") != 0) {
    mvaddstr(column++,3,Mendeleev[item++].line);
  }
  if(listcommand() == 32)
    return;
  
  clear();
  column = 4;
  item = 0;
  while(strcmp(CompressedPT[item].line,"EndOfPage") != 0) {
    mvaddstr(column++,0,CompressedPT[item++].line);
  }
  if(listcommand() == 32)
    return;
  
  clear();
  column = 0;
  item = 0;
  while(strcmp(Zhuvikin1[item].line,"EndOfPage") != 0) {
    mvaddstr(column++,0,Zhuvikin1[item++].line);
  }
  if(listcommand() == 32)
    return;
  
  clear();
  column = 0;
  item = 0;
  while(strcmp(Hefferlin1[item].line,"EndOfPage") != 0) {
    mvaddstr(column++,0,Hefferlin1[item++].line);
  }
  if(listcommand() == 32)
    return;
  
  clear();
  column = 0;
  item = 0;
  while(strcmp(ZH[item].line,"EndOfPage") != 0) {
    mvaddstr(column++,0,ZH[item++].line);
  }
  mvaddstr( 23, 16, "Press any key to Return to the Periodic Table");
  refresh();
  key = ttinp();
  return;

}


