/*

Copyright 1994 by Todd M. Miller

Permission to use, copy, modify, and distribute this
software and its documentation for any purpose and without
fee is hereby granted, provided that the above copyright
notice appear in all copies and that both that copyright
notice and this permission notice appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.
The author makes no representations about the suitability of
this software for any purpose.  It is provided "as is"
without express or implied warranty.

*/

#include <string.h>
#include "periodic.h"
#include "elements.h"
#include "info.h"

extern struct info elements[TotStructs];

void fill_specheat ( void )
{
/* Specific Heat of the Elements at 25 C.  Cp = cal / g K
 * Numbers from Kelly: Bureau of Mines Bulletin 592 (1961)
 * CRC handbook '75 page D144
 */
                  
strcpy(elements[Actinium].SpecHeat,".....");
strcpy(elements[Aluminum].SpecHeat,"0.215");
strcpy(elements[Americium].SpecHeat,".....");
strcpy(elements[Antimony].SpecHeat,"0.046");
strcpy(elements[Argon].SpecHeat,"0.124");
strcpy(elements[Arsenic].SpecHeat,"0.0785");
strcpy(elements[Astatine].SpecHeat,".....");
strcpy(elements[Barium].SpecHeat,"0.046");
strcpy(elements[Berkelium].SpecHeat,".....");
strcpy(elements[Beryllium].SpecHeat,"0.436");
strcpy(elements[Bismuth].SpecHeat,"0.0296");
strcpy(elements[Boron].SpecHeat,"0.245");
strcpy(elements[Bromine].SpecHeat,"0.113 (Br2)");
strcpy(elements[Cadminium].SpecHeat,"0.0555");
strcpy(elements[Calcium].SpecHeat,"0.156");
strcpy(elements[Californium].SpecHeat,".....");
strcpy(elements[Carbon].SpecHeat,"0.124 (dia)");
strcpy(elements[Cerium].SpecHeat,"0.049");
strcpy(elements[Cesium].SpecHeat,"0.057");
strcpy(elements[Chlorine].SpecHeat,"0.114 (Cl2)");
strcpy(elements[Chromium].SpecHeat,".....");
strcpy(elements[Cobalt].SpecHeat,"0.109");
strcpy(elements[Copper].SpecHeat,"0.092");
strcpy(elements[Curium].SpecHeat,".....");
strcpy(elements[Dysprosium].SpecHeat,"0.0414");
strcpy(elements[Einsteinum].SpecHeat,".....");
strcpy(elements[Erbium].SpecHeat,"0.0401");
strcpy(elements[Europium].SpecHeat,"0.0421");
strcpy(elements[Fermium].SpecHeat,".....");
strcpy(elements[Fluorine].SpecHeat,"0.197 (F2)");
strcpy(elements[Francium].SpecHeat,".....");
strcpy(elements[Gadolinium].SpecHeat,"0.055");
strcpy(elements[Gallium].SpecHeat,"0.098");
strcpy(elements[Germanium].SpecHeat,"0.077");
strcpy(elements[Gold].SpecHeat,"0.0308");
strcpy(elements[Hafnium].SpecHeat,"0.035");
strcpy(elements[Joliotium].SpecHeat,"N.A.");
strcpy(elements[Hahnium].SpecHeat,"N.A.");
strcpy(elements[Helium].SpecHeat,"1.24");
strcpy(elements[Holmium].SpecHeat,"0.0393");
strcpy(elements[Hydrogen].SpecHeat,"3.41 (H2)");
strcpy(elements[Indium].SpecHeat,"0.056");
strcpy(elements[Iodine].SpecHeat,"0.102");
strcpy(elements[Iridium].SpecHeat,"0.0317");
strcpy(elements[Iron].SpecHeat,"0.106");
strcpy(elements[Krypton].SpecHeat,"0.059");
strcpy(elements[Lanthanium].SpecHeat,"0.047");
strcpy(elements[Lawrencium].SpecHeat,".....");
strcpy(elements[Lead].SpecHeat,"0.038");
strcpy(elements[Lithium].SpecHeat,"0.85");
strcpy(elements[Lutetium].SpecHeat,"0.037");
strcpy(elements[Magnesium].SpecHeat,"0.243");
strcpy(elements[Manganese].SpecHeat,"0.114 (alph)");
strcpy(elements[Meitnerium].SpecHeat,"N.A.");
strcpy(elements[Mendelevium].SpecHeat,".....");
strcpy(elements[Mercury].SpecHeat,"0.0331");
strcpy(elements[Molybdenum].SpecHeat,"0.0599");
strcpy(elements[Neodymium].SpecHeat,"0.049");
strcpy(elements[Neon].SpecHeat,"0.246");
strcpy(elements[Neptunium].SpecHeat,".....");
strcpy(elements[Nickel].SpecHeat,"0.106");
strcpy(elements[Bohrium].SpecHeat,"N.A.");
strcpy(elements[Niobium].SpecHeat,"0.064");
strcpy(elements[Nitrogen].SpecHeat,"0.249 (N2)");
strcpy(elements[Nobelium].SpecHeat,"0.064");
strcpy(elements[Osmium].SpecHeat,"0.03127");
strcpy(elements[Oxygen].SpecHeat,"0.219 (O2)");
strcpy(elements[Palladium].SpecHeat,"0.0584");
strcpy(elements[Phosphorous].SpecHeat,"0.181 (whit)");
strcpy(elements[Platinum].SpecHeat,"0.0317");
strcpy(elements[Plutonium].SpecHeat,"....");
strcpy(elements[Polonium].SpecHeat,"0.030");
strcpy(elements[Potassium].SpecHeat,"0.180");
strcpy(elements[Praeseodymium].SpecHeat,"0.046");
strcpy(elements[Promethium].SpecHeat,"0.0442");
strcpy(elements[Protactinium].SpecHeat,"0.029");
strcpy(elements[Radium].SpecHeat,"0.0288");
strcpy(elements[Radon].SpecHeat,"0.0224");
strcpy(elements[Rhenium].SpecHeat,"0.0329");
strcpy(elements[Rhodium].SpecHeat,"0.0583");
strcpy(elements[Rubidium].SpecHeat,"0.0861");
strcpy(elements[Ruthenium].SpecHeat,"0.057");
strcpy(elements[Dubnium].SpecHeat,"N.A.");
strcpy(elements[Samarium].SpecHeat,"0.043");
strcpy(elements[Scandium].SpecHeat,"0.133");
strcpy(elements[Rutherfordium].SpecHeat,"N.A.");
strcpy(elements[Selenium].SpecHeat,"0.0767 (Se2)");
strcpy(elements[Silicon].SpecHeat,"0.168");
strcpy(elements[Silver].SpecHeat,"0.0566");
strcpy(elements[Sodium].SpecHeat,"0.293");
strcpy(elements[Strontium].SpecHeat,"0.0719");
strcpy(elements[Sulfur].SpecHeat,"0.175 (yllw)");
strcpy(elements[Tantalum].SpecHeat,"0.0334");
strcpy(elements[Technetium].SpecHeat,"0.058");
strcpy(elements[Tellurium].SpecHeat,"0.0481");
strcpy(elements[Terbium].SpecHeat,"0.0437");
strcpy(elements[Thallium].SpecHeat,"0.0307");
strcpy(elements[Thorium].SpecHeat,"0.0271");
strcpy(elements[Thullium].SpecHeat,"0.0382");
strcpy(elements[Tin].SpecHeat,"0.0510 (alpha)");
strcpy(elements[Titanium].SpecHeat,"0.125");
strcpy(elements[Tungsten].SpecHeat,"0.0317");
strcpy(elements[Uranium].SpecHeat,"0.0276");
strcpy(elements[Vanadium].SpecHeat,"0.116");
strcpy(elements[Xenon].SpecHeat,"0.0378");
strcpy(elements[Ytterbium].SpecHeat,"0.0346");
strcpy(elements[Yttrium].SpecHeat,"0.068");
strcpy(elements[Zinc].SpecHeat,"0.0928");
strcpy(elements[Zirconium].SpecHeat,"0.0671");
return;
}
